#Script per generare i grafici del bilanciamento del carico e confronto tra strategie.
set term post eps enhanced color "Helvetica, 22"
set grid
set key top left
set size ratio 0.7

#Font size:
set xlabel font "Helvetica, 20"
set ylabel font "Helvetica ,20"
set key font "Helvetica, 18"

#Griglia:
set style line 1 lc rgb '#808080' lt 0 lw 2
set grid back ls 1

#Risoluzione:
RESOLUTION = 50

#Grafici sulle singole strategie:
set xlabel "Elapsed execution time (sec)"
set ylabel "{/Symbol D} load difference (points)" offset 2,0,0
set title "Load balancing with the On-Demand strategy"
set output "load_od.eps"
set yrange[0:2500]
set ytics 250
set xrange[0:50000000]
set xtics ("0" 0, "10" 10000000, "20" 20000000, "30" 30000000, "40" 40000000, "50" 50000000)
plot [0:50000000] "./load_od_30.txt" using 1:2 every RESOLUTION w steps lt 1 linecolor rgb "red" title "Queue size=30.",  "./load_od_5.txt" using 1:2 every RESOLUTION w steps lt 5 lw 5 linecolor rgb "blue" title "Queue size=5.", "./load_od_1.txt" using 1:2 every RESOLUTION w steps lt 2 lw 7 linecolor rgb "green" title "Queue size=1."

set title "Load balancing with the LLW strategy"
set output "load_llw.eps"
set yrange[0:1000]
set ytics 200
plot [0:50000000] "./load_llw_10K.txt" using 1:2 every RESOLUTION w steps lt 1 linecolor rgb "red" title "Queue size=10K.", "./load_llw_100.txt" using 1:2 every RESOLUTION w steps lt 5 linecolor rgb "blue" title "Queue size=100.", "./load_llw_5.txt" using 1:2 every RESOLUTION w steps lt 2 lw 10 linecolor rgb "green" title "Queue size=5."

set title "Load balancing with the LLW+ strategy"
set output "load_llw+.eps"
set yrange[0:200]
set ytics 20
plot [0:50000000] "./load_llw+_10K.txt" using 1:2 every RESOLUTION w steps lt 1 linecolor rgb "red" title "Queue size=10K.", "./load_llw+_100.txt" using 1:2 every RESOLUTION w steps lt 5 linecolor rgb "blue" title "Queue size=100.", "./load_llw+_5.txt" using 1:2 every RESOLUTION w steps lt 2 linecolor rgb "green" title "Queue size=5."

#Grafici di confronto tra strategie:
set yrange[0:180]
set ytics 36
set ylabel "{/Symbol D} load difference (points)" offset 2,0,0
set title "Load balancing with low Queue sizes"
set output "load_comp_low.eps"
plot [0:50000000] "./load_od_1.txt" using 1:2 every RESOLUTION w steps lt 1 linecolor rgb "red" title "OD-Queue size=1.", "./load_rr_5.txt" using 1:2 every RESOLUTION w steps lt 10 linecolor rgb "blue" title "RR-Queue size=5.", "./load_llw_5.txt" using 1:2 every RESOLUTION w steps lt 5 lw 8 linecolor rgb "black" title "LLW-Queue size=5.", "./load_llw+_5.txt" using 1:2 every RESOLUTION w steps lt 2 linecolor rgb "green" title "LLW+-Queue size=5."

set output "load_comp_high.eps"
set yrange[0:1000]
set ytics 100
set title "Load balancing with high Queue sizes"
plot [0:50000000] "./load_llw_10K.txt" using 1:2 every RESOLUTION w steps lt 1 linecolor rgb "red" title "LLW-Queue sizes=10K.", "./load_llw+_10K.txt" using 1:2 every RESOLUTION w steps lt 2 linecolor rgb "green" title "LLW+-Queue size=10K.",  "./load_rr_10K.txt" using 1:2 every RESOLUTION w steps lt 10 linecolor rgb "blue" title "RR-Queue size=10K."

system("sh crop.sh")